@@ -19,7 +19,7 @@ DEFAULT_HOST = "v2.decipherinc.com"
 
 def date_to_isoformat(o):
     # convert local timestap to iso8601 format
-    time.strftime("%FT%TZ", time.gmtime(int(o.strftime("%s"))))
+    return time.strftime("%FT%TZ", time.gmtime(int(o.strftime("%s"))))
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
